==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/VeleroBackupConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VeleroBackupConfigFluent<A extends VeleroBackupConfigFluent<A>> extends BaseFluent<A>{
  public VeleroBackupConfigFluent() {
  }
  public VeleroBackupConfigFluent(VeleroBackupConfig instance) {
    instance = (instance != null ? instance : new VeleroBackupConfig());

    if (instance != null) {
      this.withEnabled(instance.getEnabled());
      this.withEnabled(instance.getEnabled());
    }
  }
  private Boolean enabled;
  public Boolean getEnabled() {
    return this.enabled;
  }
  public A withEnabled(Boolean enabled) {
    this.enabled=enabled; return (A) this;
  }
  public boolean hasEnabled() {
    return this.enabled != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VeleroBackupConfigFluent that = (VeleroBackupConfigFluent) o;
    if (!java.util.Objects.equals(enabled, that.enabled)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(enabled,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enabled != null) { sb.append("enabled:"); sb.append(enabled); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnabled() {
    return withEnabled(true);
  }
  
}

==> open-cluster-management-operator-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/VeleroBackupConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class VeleroBackupConfigFluent<A extends VeleroBackupConfigFluent<A>> extends BaseFluent<A>{
  public VeleroBackupConfigFluent() {
  }
  
  public VeleroBackupConfigFluent(VeleroBackupConfig instance) {
    this.copyInstance(instance);
  }
  private Boolean enabled;
  
  protected void copyInstance(VeleroBackupConfig instance) {
    instance = (instance != null ? instance : new VeleroBackupConfig());
    if (instance != null) {
          this.withEnabled(instance.getEnabled());
          this.withEnabled(instance.getEnabled());
        }
  }
  
  public Boolean getEnabled() {
    return this.enabled;
  }
  
  public A withEnabled(Boolean enabled) {
    this.enabled = enabled;
    return (A) this;
  }
  
  public boolean hasEnabled() {
    return this.enabled != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VeleroBackupConfigFluent that = (VeleroBackupConfigFluent) o;
    if (!java.util.Objects.equals(enabled, that.enabled)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(enabled,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (enabled != null) { sb.append("enabled:"); sb.append(enabled); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withEnabled() {
    return withEnabled(true);
  }
  

}
